@@ -14,8 +14,6 @@
 
 """Exceptions for the Brick library."""
 
-from __future__ import annotations
-
 import traceback
 from typing import Any, Optional
 
@@ -168,6 +166,11 @@ class InvalidConnectorProtocol(ValueError):
     pass
 
 
+class MultipathdPathsNotRemoved(BrickException):
+    message = _("The following devices %(devices)s are still not removed "
+                "from multipathd monitoring")
+
+
 class ExceptionChainer(BrickException):
     """A Exception that can contain a group of exceptions.
 
