@@ -78,15 +78,17 @@ class ScaleIOConnector(base.BaseLinuxConnector):
         self.verify_certificate = None
         self.certificate_path = None
 
-    def _get_guid(self):
+    def _get_guid(self, log_error=True):
         try:
             guid = priv_scaleio.get_guid(self.GET_GUID_OP_CODE)
             LOG.info("Current sdc guid: %s", guid)
             return guid
         except (IOError, OSError, ValueError) as e:
-            msg = _("Error querying sdc guid: %s") % e
-            LOG.error(msg)
-            raise exception.BrickException(message=msg)
+            msg = _("Failed to query sdc guid: %s") % e
+            if log_error:
+                LOG.error(msg)
+                raise exception.BrickException(message=msg)
+            LOG.debug(msg)
 
     @staticmethod
     def _get_password_token(connection_properties):
@@ -125,13 +127,9 @@ class ScaleIOConnector(base.BaseLinuxConnector):
         props = {}
         scaleio = ScaleIOConnector(root_helper=root_helper,
                                    execute=kwargs.get('execute'))
-        try:
-            guid = scaleio._get_guid()
-            if guid:
-                props['sdc_guid'] = guid
-        except Exception as e:
-            msg = _("Unable to find SDC guid: %s") % e
-            LOG.info(msg)
+        guid = scaleio._get_guid(log_error=False)
+        if guid:
+            props['sdc_guid'] = guid
         return props
 
     def get_search_path(self):
@@ -396,9 +394,11 @@ class ScaleIOConnector(base.BaseLinuxConnector):
             }
         )
 
-        if self.no_secret:
-            # Since there is no connector configuration,
-            # the driver has done mapping and set QoS.
+        # The new volume attachment always handle on
+        # the driver side.
+        if "sdc_guid" in connection_properties:
+            LOG.info("ScaleIO map volume %(volume_name)s handle on "
+                     "driver side", {'volume_name': self.volume_name})
             self.volume_path = self._find_volume_path()
             device_info['path'] = self.volume_path
             return device_info
@@ -519,12 +519,16 @@ class ScaleIOConnector(base.BaseLinuxConnector):
              'server_ip': self.server_ip}
         )
 
-        # Since there is no connector configuration,
-        # the driver will unmap the volume.
-        if self.no_secret:
+        if "sdc_guid" in connection_properties:
+            LOG.info("ScaleIO volume : (%(volume_name)s) unmap "
+                     "handle on driver side.",
+                     {'volume_name': self.volume_name})
             return
 
-        # The old routine with connector configuration
+        # The legacy volume unmap handle on os-brick side
+        LOG.info("ScaleIO legacy volume : (%(volume_name)s) unmap "
+                 "handle on os-brick side.",
+                 {'volume_name': self.volume_name})
         self.volume_id = self.volume_id or self._get_volume_id()
 
         guid = self._get_guid()
@@ -603,7 +607,3 @@ class ScaleIOConnector(base.BaseLinuxConnector):
             LOG.info("ScaleIO disconnect volume %(volume_id)s "
                      "removed at path %(path)s.",
                      {'volume_id': self.volume_id, 'path': path})
-
-    @property
-    def no_secret(self):
-        return not self.server_password and not self.server_token
