@@ -12,10 +12,8 @@
 
 """Generic RBD connection utilities."""
 
-from __future__ import annotations
-
 import io
-from typing import NoReturn, Optional  # noqa: H301
+from typing import NoReturn, Optional
 
 from oslo_log import log as logging
 
@@ -61,8 +59,6 @@ class RBDClient(object):
 
         self.rbd_conf: str = kwargs.get('conffile', '/etc/ceph/ceph.conf')
         self.rbd_cluster_name: str = kwargs.get('rbd_cluster_name', 'ceph')
-        self.rados_connect_timeout: int = kwargs.get('rados_connect_timeout',
-                                                     -1)
 
         self.client, self.ioctx = self.connect()
 
@@ -73,18 +69,13 @@ class RBDClient(object):
         self.disconnect()
 
     def connect(self) -> tuple['rados.Rados', 'rados.Ioctx']:
-        LOG.debug("opening connection to ceph cluster (timeout=%s).",
-                  self.rados_connect_timeout)
+        LOG.debug("opening connection to ceph cluster")
         client = self.rados.Rados(rados_id=self.rbd_user,
                                   clustername=self.rbd_cluster_name,
                                   conffile=self.rbd_conf)
 
         try:
-            if self.rados_connect_timeout >= 0:
-                client.connect(
-                    timeout=self.rados_connect_timeout)
-            else:
-                client.connect()
+            client.connect()
             ioctx = client.open_ioctx(self.rbd_pool)
             return client, ioctx
         except self.rados.Error:
@@ -242,18 +233,31 @@ class RBDVolumeIOWrapper(io.RawIOBase):
     def flush(self) -> None:
         # Raise ValueError if already closed
         super().flush()
+        # Don't fail on flush by calling it when underlying image is closed.
         try:
-            self._rbd_volume.image.flush()
+            self.rbd_image.require_not_closed()
+        except rbd.InvalidArgument:  # Image is closed
+            LOG.warning("RBDVolumeIOWrapper's underlying image %s was closed "
+                        "directly (probably by the GC) instead of through the "
+                        "wrapper", self.rbd_image.name)
+            return
+
+        try:
+            self.rbd_image.flush()
         except AttributeError:
             LOG.warning("flush() not supported in this version of librbd")
 
     def fileno(self) -> NoReturn:
-        """RBD does not have support for fileno() so we raise IOError.
+        """RBD does not have support for fileno().
 
-        Raising IOError is recommended way to notify caller that interface is
-        not supported - see http://docs.python.org/2/library/io.html#io.IOBase
+        Raises an OSError subclass as recommended by
+        http://docs.python.org/3/library/io.html#io.IOBase .
         """
-        raise IOError(_("fileno() not supported by RBD()"))
+
+        # (JSc) We actually use io.UnsupportedOperation here, because that is
+        # what requests explicitly checks against. Raising anything else
+        # would make it impossible to use Rbd objects with requests.
+        raise io.UnsupportedOperation(_("fileno() not supported by RBD()"))
 
     def close(self) -> None:
         if not self.closed:
