@@ -10,19 +10,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
-
 from oslo_privsep import capabilities as c
 from oslo_privsep import priv_context
 
 
-capabilities = [c.CAP_SYS_ADMIN]
-
-# On virtual environments libraries are not owned by the Daemon user (root), so
-# the Daemon needs the capability to bypass file read permission checks in
-# order to dynamically load the code to run.
-if os.environ.get('VIRTUAL_ENV'):
-    capabilities.append(c.CAP_DAC_READ_SEARCH)
+capabilities = [c.CAP_SYS_ADMIN, c.CAP_DAC_READ_SEARCH]
 
 # It is expected that most (if not all) os-brick operations can be
 # executed with these privileges.
@@ -31,4 +23,13 @@ default = priv_context.PrivContext(
     cfg_section='privsep_osbrick',
     pypath=__name__ + '.default',
     capabilities=capabilities,
+    logger_name=__name__,
+)
+
+brick_privsep_hide_output = priv_context.PrivContext(
+    __name__,
+    cfg_section='privsep_osbrick',
+    pypath=__name__ + '.brick_privsep_hide_output',
+    capabilities=capabilities,
+    logger_name='brick_privsep_hide_output',
 )
