@@ -339,8 +339,9 @@ class RBDConnectorTestCase(test_base_rbd.RBDConnectorTestMixin,
 
         mock_execute.assert_called_once_with(
             'rbd', 'unmap', '/dev/rbd0', '--id', 'fake_user', '--mon_host',
-            '192.168.10.2:6789', '--conf', mock.sentinel.conf,
-            root_helper=connector._root_helper, run_as_root=True)
+            '192.168.10.2:6789,192.168.10.3:6789', '--conf',
+            mock.sentinel.conf, root_helper=connector._root_helper,
+            run_as_root=True)
         mock_delete.assert_called_once_with(mock.sentinel.conf)
 
     @mock.patch.object(priv_rootwrap, 'execute', return_value=None)
@@ -358,8 +359,8 @@ class RBDConnectorTestCase(test_base_rbd.RBDConnectorTestMixin,
         rbd_connector.disconnect_volume(conn, None)
 
         # Assert that only showmapped is called when no mappings are found
-        mock_execute.called_once_with(*show_cmd, root_helper=None,
-                                      run_as_root=True)
+        mock_execute.assert_called_once_with(*show_cmd, root_helper=None,
+                                             run_as_root=True)
 
     @mock.patch.object(priv_rootwrap, 'execute', return_value=None)
     def test_disconnect_local_volume_no_mappings(self, mock_execute):
@@ -374,8 +375,8 @@ class RBDConnectorTestCase(test_base_rbd.RBDConnectorTestMixin,
         rbd_connector.disconnect_volume(conn, None)
 
         # Assert that only showmapped is called when no mappings are found
-        mock_execute.called_once_with(*show_cmd, root_helper=None,
-                                      run_as_root=True)
+        mock_execute.assert_called_once_with(*show_cmd, root_helper=None,
+                                             run_as_root=True)
 
     @mock.patch('oslo_utils.fileutils.delete_if_exists')
     @mock.patch.object(rbd.RBDConnector, '_get_rbd_handle')
@@ -383,7 +384,8 @@ class RBDConnectorTestCase(test_base_rbd.RBDConnectorTestMixin,
         connector = rbd.RBDConnector(None)
         res = connector.extend_volume(self.connection_properties)
 
-        mock_handle.assert_called_once_with(self.connection_properties)
+        mock_handle.assert_called_once_with(self.connection_properties,
+                                            read_only=True)
         mock_handle.return_value.seek.assert_called_once_with(0, 2)
         mock_handle.return_value.tell.assert_called_once_with()
         self.assertIs(mock_handle().tell(), res)
@@ -399,7 +401,8 @@ class RBDConnectorTestCase(test_base_rbd.RBDConnectorTestMixin,
         self.assertRaises(ValueError, connector.extend_volume,
                           self.connection_properties)
 
-        mock_handle.assert_called_once_with(self.connection_properties)
+        mock_handle.assert_called_once_with(self.connection_properties,
+                                            read_only=True)
         mock_handle.return_value.seek.assert_called_once_with(0, 2)
         mock_handle().tell.assert_not_called()
         mock_delete.assert_called_once_with(mock_handle.return_value.rbd_conf)
