@@ -204,13 +204,6 @@ class ConnectorTestCase(test_base.TestCase):
 
             self.assertEqual(expected_props, props)
 
-    @mock.patch('sys.platform', 'win32')
-    def test_get_connector_mapping_win32(self):
-        mapping_win32 = connector.get_connector_mapping()
-        self.assertIn('ISCSI', mapping_win32)
-        self.assertIn('RBD', mapping_win32)
-        self.assertNotIn('STORPOOL', mapping_win32)
-
     @mock.patch('os_brick.initiator.connector.platform.machine')
     def test_get_connector_mapping(self, mock_platform_machine):
         mock_platform_machine.return_value = 'x86_64'
