@@ -17,6 +17,7 @@ from unittest import mock
 from oslo_concurrency import processutils
 
 from os_brick import exception
+from os_brick import executor as os_brick_executor
 from os_brick.local_dev import lvm as brick
 from os_brick.privileged import rootwrap as priv_rootwrap
 from os_brick.tests import base
@@ -73,12 +74,14 @@ class BrickLvmTestCase(base.TestCase):
                 cmd_string):
             data = "  fake-vg\n"
             data += "  some-other-vg\n"
-        elif (_lvm_prefix + 'vgs, --noheadings, -o, name, fake-vg' ==
-                cmd_string):
+        elif (_lvm_prefix +
+              'vgs, --noheadings, -o, name, --readonly, fake-vg' ==
+              cmd_string):
             data = "  fake-vg\n"
         elif _lvm_prefix + 'vgs, --version' in cmd_string:
             data = "  LVM version:     2.02.95(2) (2012-03-06)\n"
-        elif (_lvm_prefix + 'vgs, --noheadings, -o, uuid, fake-vg' in
+        elif (_lvm_prefix +
+              'vgs, --noheadings, -o, uuid, --readonly, fake-vg' in
               cmd_string):
             data = "  kVxztV-dKpG-Rz7E-xtKY-jeju-QsYU-SLG6Z1\n"
         elif _lvm_prefix + 'vgs, --noheadings, --unit=g, ' \
@@ -101,17 +104,17 @@ class BrickLvmTestCase(base.TestCase):
             data += "  fake-vg-3:10.00:10.00:0:"\
                     "mXzbuX-dKpG-Rz7E-xtKY-jeju-QsYU-SLG8Z3\n"
         elif (_lvm_prefix + 'lvs, --noheadings, '
-              '--unit=g, -o, vg_name,name,size, --nosuffix, '
+              '--unit=g, -o, vg_name,name,size, --nosuffix, --readonly, '
               'fake-vg/lv-nothere' in cmd_string):
             raise processutils.ProcessExecutionError(
                 stderr="One or more specified logical volume(s) not found.")
         elif (_lvm_prefix + 'lvs, --noheadings, '
-              '--unit=g, -o, vg_name,name,size, --nosuffix, '
+              '--unit=g, -o, vg_name,name,size, --nosuffix, --readonly, '
               'fake-vg/lv-newerror' in cmd_string):
             raise processutils.ProcessExecutionError(
                 stderr="Failed to find logical volume \"fake-vg/lv-newerror\"")
         elif (_lvm_prefix + 'lvs, --noheadings, '
-              '--unit=g, -o, vg_name,name,size' in cmd_string):
+              '--unit=g, -o, vg_name,name,size, ' in cmd_string):
             if 'fake-unknown' in cmd_string:
                 raise processutils.ProcessExecutionError(
                     stderr="One or more volume(s) not found."
@@ -227,6 +230,39 @@ class BrickLvmTestCase(base.TestCase):
                 'sudo', vg_name='fake-vg')
         )
 
+    @mock.patch('tenacity.nap.sleep', mock.Mock())
+    @mock.patch.object(brick.putils, 'execute')
+    def test_get_lv_info_retry(self, exec_mock):
+        exec_mock.side_effect = (
+            processutils.ProcessExecutionError('', '', exit_code=139),
+            ('vg name size', ''),
+        )
+        self.assertEqual(
+            [{'name': 'fake-1', 'size': '1.00g', 'vg': 'fake-vg'},
+             {'name': 'fake-2', 'size': '1.00g', 'vg': 'fake-vg'}],
+            self.vg.get_lv_info('sudo', vg_name='vg', lv_name='name')
+        )
+
+    @mock.patch('tenacity.nap.sleep', mock.Mock())
+    @mock.patch.object(os_brick_executor.Executor, '_execute')
+    def test_get_thin_pool_free_space_retry(self, exec_mock):
+        exec_mock.side_effect = (
+            processutils.ProcessExecutionError('', '', exit_code=139),
+            ('15.84:50', ''),
+        )
+        self.assertEqual(
+            7.92,
+            self.vg._get_thin_pool_free_space('vg', 'thinpool')
+        )
+        self.assertEqual(2, exec_mock.call_count)
+        args = ['env', 'LC_ALL=C', 'lvs', '--noheadings', '--unit=g', '-o',
+                'size,data_percent', '--separator', ':', '--nosuffix',
+                '--readonly', '/dev/vg/thinpool']
+        if self.configuration.lvm_suppress_fd_warnings:
+            args.insert(2, 'LVM_SUPPRESS_FD_WARNINGS=1')
+        lvs_call = mock.call(*args, root_helper='sudo', run_as_root=True)
+        exec_mock.assert_has_calls([lvs_call, lvs_call])
+
     def test_get_all_physical_volumes(self):
         # Filtered VG version
         pvs = self.vg.get_all_physical_volumes('sudo', 'fake-vg')
@@ -245,55 +281,6 @@ class BrickLvmTestCase(base.TestCase):
         self.assertEqual(1,
                          len(self.vg.get_all_volume_groups('sudo', 'fake-vg')))
 
-    def test_thin_support(self):
-        # lvm.supports_thin() is a static method and doesn't
-        # use the self._executor fake we pass in on init
-        # so we need to stub processutils.execute appropriately
-
-        with mock.patch.object(priv_rootwrap, 'execute',
-                               side_effect=self.fake_execute):
-            self.assertTrue(self.vg.supports_thin_provisioning('sudo'))
-
-        with mock.patch.object(priv_rootwrap, 'execute',
-                               side_effect=self.fake_pretend_lvm_version):
-            self.assertTrue(self.vg.supports_thin_provisioning('sudo'))
-
-        with mock.patch.object(priv_rootwrap, 'execute',
-                               side_effect=self.fake_old_lvm_version):
-            self.assertFalse(self.vg.supports_thin_provisioning('sudo'))
-
-        with mock.patch.object(priv_rootwrap, 'execute',
-                               side_effect=self.fake_customised_lvm_version):
-            self.assertTrue(self.vg.supports_thin_provisioning('sudo'))
-
-    def test_snapshot_lv_activate_support(self):
-        self.vg._supports_snapshot_lv_activation = None
-        with mock.patch.object(priv_rootwrap, 'execute',
-                               side_effect=self.fake_execute):
-            self.assertTrue(self.vg.supports_snapshot_lv_activation)
-
-        self.vg._supports_snapshot_lv_activation = None
-        with mock.patch.object(priv_rootwrap, 'execute',
-                               side_effect=self.fake_old_lvm_version):
-            self.assertFalse(self.vg.supports_snapshot_lv_activation)
-
-        self.vg._supports_snapshot_lv_activation = None
-
-    def test_lvchange_ignskipact_support_yes(self):
-        """Tests if lvchange -K is available via a lvm2 version check."""
-
-        self.vg._supports_lvchange_ignoreskipactivation = None
-        with mock.patch.object(priv_rootwrap, 'execute',
-                               side_effect=self.fake_pretend_lvm_version):
-            self.assertTrue(self.vg.supports_lvchange_ignoreskipactivation)
-
-        self.vg._supports_lvchange_ignoreskipactivation = None
-        with mock.patch.object(priv_rootwrap, 'execute',
-                               side_effect=self.fake_old_lvm_version):
-            self.assertFalse(self.vg.supports_lvchange_ignoreskipactivation)
-
-        self.vg._supports_lvchange_ignoreskipactivation = None
-
     def test_thin_pool_creation_manual(self):
         # The size of fake-vg volume group is 10g, so the calculated thin
         # pool size should be 9.5g (95% of 10g).
@@ -373,7 +360,7 @@ class BrickLvmTestCase(base.TestCase):
         self.assertFalse(self.vg.deactivate_lv.called)
 
     def test_lv_deactivate(self):
-        with mock.patch.object(self.vg, '_execute'):
+        with mock.patch.object(self.vg, '_execute', return_value=(0, 0)):
             is_active_mock = mock.Mock()
             is_active_mock.return_value = False
             self.vg._lv_is_active = is_active_mock
@@ -382,7 +369,7 @@ class BrickLvmTestCase(base.TestCase):
 
     @mock.patch('os_brick.utils._time_sleep')
     def test_lv_deactivate_timeout(self, mock_sleep):
-        with mock.patch.object(self.vg, '_execute'):
+        with mock.patch.object(self.vg, '_execute', return_value=(0, 0)):
             is_active_mock = mock.Mock()
             is_active_mock.return_value = True
             self.vg._lv_is_active = is_active_mock
