@@ -12,19 +12,20 @@
 #
 """Utilities and helper functions."""
 
-from __future__ import annotations
-
+import binascii
 import functools
 import inspect
 import logging as py_logging
 import os
 import time
-from typing import Any, Callable, Optional, Type, Union   # noqa: H301
+from typing import Any, Callable, Optional, Type, Union
+import uuid as uuid_lib
 
 from oslo_concurrency import processutils
 from oslo_log import log as logging
 from oslo_utils import strutils
 
+from os_brick import executor
 from os_brick.i18n import _
 from os_brick.privileged import nvmeof as priv_nvme
 from os_brick.privileged import rootwrap as priv_rootwrap
@@ -219,17 +220,43 @@ def convert_str(text: Union[bytes, str]) -> str:
         return text
 
 
-def get_host_nqn() -> Optional[str]:
+def get_host_nqn(system_uuid: Optional[str] = None) -> Optional[str]:
+    """Ensure that hostnqn exists, creating if necessary.
+
+    This method tries to return contents from /etc/nvme/hostnqn and if not
+    possible then creates the file calling create_hostnqn and passing provided
+    system_uuid and returns the contents of the newly created file.
+
+    Method create_hostnqn gives priority to the provided system_uuid parameter
+    for the contents of the file over other alternatives it has.
+    """
     try:
         with open('/etc/nvme/hostnqn', 'r') as f:
             host_nqn = f.read().strip()
     except IOError:
-        host_nqn = priv_nvme.create_hostnqn()
+        host_nqn = priv_nvme.create_hostnqn(system_uuid)
     except Exception:
         host_nqn = None
     return host_nqn
 
 
+def get_nvme_host_id(uuid: Optional[str]) -> Optional[str]:
+    """Get the nvme host id
+
+    If the hostid file doesn't exist create it either with the passed uuid or
+    a random one.
+    """
+    try:
+        with open('/etc/nvme/hostid', 'r') as f:
+            host_id = f.read().strip()
+    except IOError:
+        uuid = uuid or str(uuid_lib.uuid4())
+        host_id = priv_nvme.create_hostid(uuid)
+    except Exception:
+        host_id = None
+    return host_id
+
+
 def _symlink_name_from_device_path(device_path):
     """Generate symlink absolute path for encrypted devices.
 
@@ -400,7 +427,7 @@ def connect_volume_undo_prepare_result(
     return decorator
 
 
-def get_device_size(executor, device):
+def get_device_size(executor: executor.Executor, device: str) -> Optional[int]:
     """Get the size in bytes of a volume."""
     (out, _err) = executor._execute('blockdev', '--getsize64',
                                     device, run_as_root=True,
@@ -412,6 +439,57 @@ def get_device_size(executor, device):
         return None
 
 
+def check_valid_device(executor: executor.Executor, path: str) -> bool:
+    cmd = ('dd', 'if=%(path)s' % {"path": path},
+           'of=/dev/null', 'count=1')
+    out, info = None, None
+    try:
+        out, info = executor._execute(*cmd, run_as_root=True,
+                                      root_helper=executor._root_helper)
+    except processutils.ProcessExecutionError as e:
+        LOG.error("Failed to access the device on the path "
+                  "%(path)s: %(error)s.",
+                  {"path": path, "error": e.stderr})
+        return False
+    # If the info is none, the path does not exist.
+    return info is not None
+
+
+def get_passphrase_from_secret(key) -> str:
+    """Convert encryption key retrieved from the Key Manager into a passphrase.
+
+    If the secret type is 'passphrase', assume that the key is already in
+    a suitable string format and simply return it.
+    In any other case, assume a binary key that needs to be converted into
+    an ASCII representation using binascii.hexlify().
+
+    Cinder uses 'symmetric' in conjunction with binascii.hexlify() to
+    handle encryption keys for its own volumes and resulting volume images.
+    Nova uses the 'passphrase' type instead for its qcow2+LUKS images which
+    are directly passed to LUKS as passphrase input. User-defined Glance
+    images may reference secrets of any type (defaulting to 'opaque') which
+    we optimistically assume to represent binary keys too (unless their
+    type is 'passphrase' explicitly).
+
+    :param key: Key Manager Secret containing the encryption key
+    :type key: castellan.common.objects.managed_object.ManagedObject
+    :return: passphrase
+    :rtype: str
+    """
+    if key.managed_type() == 'passphrase':
+        LOG.debug(
+            "os_brick.utils.get_passphrase_from_secret: the secret is of type "
+            "passphrase and will be used without conversion"
+        )
+        return key.get_encoded().decode('utf-8')
+    else:
+        LOG.debug(
+            "os_brick.utils.get_passphrase_from_secret: the secret is not of "
+            "type passphrase and will be converted using hex representation"
+        )
+        return binascii.hexlify(key.get_encoded()).decode('utf-8')
+
+
 class Anything(object):
     """Object equal to everything."""
     def __eq__(self, other):
